GeneralFrameworkClient<AGeneralFrameworkClientEnsureInitializedValue extends GeneralFrameworkClientEnsureInitialized, AGeneralFrameworkClientInvokeValueOptions extends GeneralFrameworkClientInvokeOptions, AGeneralFrameworkClientRequestDefaultValue extends GeneralFrameworkClientInvokeOptions, AGeneralFrameworkDatabaseValue extends GeneralFrameworkDatabase<GeneralFrameworkDatabaseEnsureInitialized>, AGeneralFrameworkApiValue extends GeneralFrameworkApiBase<GeneralFrameworkApiEnsureInitialized, GeneralFrameworkDatabase<GeneralFrameworkDatabaseEnsureInitialized>, dynamic>> class abstract

GeneralFrameworkClient is universal client for help you connection to rest api server super easy friendly

Inheritance
  • Object
  • GeneralSchemaBaseCore<AGeneralFrameworkClientEnsureInitializedValue>
  • GeneralSchemaClient<AGeneralFrameworkClientEnsureInitializedValue, JsonScheme, AGeneralFrameworkClientInvokeValueOptions, AGeneralFrameworkClientRequestDefaultValue, AGeneralFrameworkDatabaseValue, AGeneralFrameworkApiValue>
  • GeneralFrameworkClient

Constructors

GeneralFrameworkClient({required String pathApi, required String pathWebSocket, required GeneralSystemDeviceLibrary generalLibrary, required String apiUrl, required NetworkClientConnectionType networkClientConnectionType, required AGeneralFrameworkDatabaseValue generalSchemaDatabase, required AGeneralFrameworkApiValue generalSchemaApi, required AGeneralFrameworkClientRequestDefaultValue requestDefault, EventEmitter? eventEmitter, String eventUpdate = "update", String eventInvoke = "invoke", Client? httpClient})
UncompleteDocumentation

Properties

api_uri → Uri
UncompleteDocumentation
no setter
apiUrl → String
UncompleteDocumentation
final
currentPath ↔ String
UncompleteDocumentation
latefinal
event_emitter → EventEmitter
UncompleteDocumentation
final
eventInvoke → String
UncompleteDocumentation
final
eventUpdate → String
UncompleteDocumentation
final
generalLibrary → GeneralSystemDeviceLibrary
UncompleteDocumentation
final
generalSchemaApi → AGeneralFrameworkApiValue
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
finalinherited
generalSchemaDatabase → AGeneralFrameworkDatabaseValue
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
finalinherited
generalSchemaEnsureInitialized ↔ AGeneralFrameworkClientEnsureInitializedValue
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
http_client → Client
UncompleteDocumentation
final
is_initialized ↔ bool
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
getter/setter pair
networkClientConnectionType → NetworkClientConnectionType
UncompleteDocumentation
final
pathApi → String
UncompleteDocumentation
final
pathWebSocket → String
UncompleteDocumentation
final
requestDefault → AGeneralFrameworkClientRequestDefaultValue
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tcp_socket_client → TcpSocketClient
UncompleteDocumentation
final
web_socket_client → WebSocketClient
UncompleteDocumentation
final

Methods

decryptData({required String data}) → String
UncompleteDocumentation
dispose() → FutureOr<void>
GeneralLib
inherited
emit({required String event_name, required Object data}) → void
UncompleteDocumentation
encryptData({required Map data}) → String
UncompleteDocumentation
ensureInitialized({required AGeneralFrameworkClientEnsureInitializedValue generalSchemaEnsureInitialized}) → FutureOr<void>
GeneralLib
override
getDetailStatusDeviceSupportAsync() → FutureOr<GeneralSchemaDeviceStatusSupportType>
GeneralLib
inherited
getDetailStatusDeviceSupportSync() → GeneralSchemaDeviceStatusSupportType
GeneralLib
inherited
getLibraryStatusTypeAsync() → FutureOr<GeneralSchemaLibraryStatusType>
GeneralLib
inherited
getLibraryStatusTypeSync() → GeneralSchemaLibraryStatusType
GeneralLib
inherited
initialized() → FutureOr<void>
GeneralLib
override
invoke({required JsonScheme invokeParameters, required AGeneralFrameworkClientInvokeValueOptions? invokeOptions}) → FutureOr<JsonScheme>
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
inherited
invokeBuilder<T>({required JsonScheme invokeParameters, required AGeneralFrameworkClientInvokeValueOptions? invokeOptions, required FutureOr<T> onResult(JsonScheme result)}) → FutureOr<T>
UncompleteDocumentation
invokeRaw({required JsonScheme invokeParameters, required AGeneralFrameworkClientInvokeValueOptions? invokeOptions}) → Future<JsonScheme>
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
override
isDeviceSupportAsync() → FutureOr<bool>
GeneralLib
inherited
isDeviceSupportSync() → bool
GeneralLib
inherited
language({String? languageCodeId}) → Language
UncompleteDocumentation
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on({required String event_name, required FutureOr callback(Map update), required FutureOr onError(Object e, StackTrace stackTrace)}) → EventEmitterListener
UncompleteDocumentation
onSocketConnection(SocketConnection socketConnection) → FutureOr<void>
UncompleteDocumentation
onSocketData(dynamic data) → Future<void>
UncompleteDocumentation
request({required JsonScheme invokeParameters, required AGeneralFrameworkClientInvokeValueOptions? invokeOptions}) → FutureOr<JsonScheme>
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
inherited
toString() → String
A string representation of this object.
inherited
utils_checkResult({required Map result}) → void
UncompleteDocumentation
utils_generateExtra({required int length, String schema = "0123456789abcdefghijklmnopqrstuvwxyz-_"}) → String
UncompleteDocumentation
utils_getExtra({required Map parameters}) → String
UncompleteDocumentation
valueBuilderAsync<T extends Object?>({required FutureOr<T> onValueBuilder(), required FutureOr<T> onErrorValueBuilder(dynamic error, StackTrace stackTrace)}) → FutureOr<T>
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
inherited
valueBuilderSync<T extends Object?>({required T onValueBuilder(), required T onErrorValueBuilder(dynamic error, StackTrace stackTrace)}) → T
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited