GeneralFrameworkClientInvokeOptions class

UncompleteDocumentation

Constructors

GeneralFrameworkClientInvokeOptions({required NetworkClientConnectionType networkClientConnectionType, required Duration durationTimeOut, required bool isInvokeThrowOnError})
UncompleteDocumentation

Properties

durationTimeOut → Duration
UncompleteDocumentation
final
hashCode → int
The hash code for this object.
no setterinherited
isInvokeThrowOnError → bool
UncompleteDocumentation
final
networkClientConnectionType → NetworkClientConnectionType
UncompleteDocumentation
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({NetworkClientConnectionType? networkClientConnectionType, Duration? durationTimeOut, bool? isInvokeThrowOnError}) → GeneralFrameworkClientInvokeOptions
UncompleteDocumentation
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited