GeneralFrameworkApiDatabaseDummy class

General Library Documentation Undocument By General Corporation & Global Corporation & General Developer

Inheritance

Constructors

GeneralFrameworkApiDatabaseDummy()
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer

Properties

directory_base → Directory
UncompleteDocumentation
no setteroverride
generalSchemaEnsureInitialized ↔ GeneralFrameworkDatabaseEnsureInitialized
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → FutureOr<void>
GeneralLib
override
ensureInitialized({required GeneralFrameworkDatabaseEnsureInitialized generalSchemaEnsureInitialized}) → FutureOr<void>
GeneralLib
inherited
ensureInitializedDatabase() → void
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
override
getDetailStatusDeviceSupportAsync() → FutureOr<GeneralSchemaDeviceStatusSupportType>
GeneralLib
override
getDetailStatusDeviceSupportSync() → GeneralSchemaDeviceStatusSupportType
GeneralLib
override
getLibraryStatusTypeAsync() → FutureOr<GeneralSchemaLibraryStatusType>
GeneralLib
override
getLibraryStatusTypeSync() → GeneralSchemaLibraryStatusType
GeneralLib
override
initialized() → FutureOr<void>
GeneralLib
override
isDeviceSupportAsync() → FutureOr<bool>
GeneralLib
override
isDeviceSupportSync() → bool
GeneralLib
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
valueBuilderAsync<T extends Object?>({required FutureOr<T> onValueBuilder(), required FutureOr<T> onErrorValueBuilder(dynamic error, StackTrace stackTrace)}) → FutureOr<T>
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
inherited
valueBuilderSync<T extends Object?>({required T onValueBuilder(), required T onErrorValueBuilder(dynamic error, StackTrace stackTrace)}) → T
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited