GeneralFrameworkApiServer<AGeneralFrameworkApiServerEnsureInitializedValue extends GeneralFrameworkApiServerEnsureInitialized, AGeneralFrameworkApiSchemaApiValue extends GeneralFrameworkApiBase<GeneralFrameworkApiEnsureInitialized, GeneralFrameworkDatabase<GeneralFrameworkDatabaseEnsureInitialized>, dynamic>> class abstract

General Library Documentation Undocument By General Corporation & Global Corporation & General Developer

Inheritance
  • Object
  • GeneralSchemaBaseCore<AGeneralFrameworkApiServerEnsureInitializedValue>
  • GeneralSchemaServer<AGeneralFrameworkApiServerEnsureInitializedValue, AGeneralFrameworkApiSchemaApiValue>
  • GeneralFrameworkApiServer

Constructors

GeneralFrameworkApiServer({required ServerUniverseNative serverUniverse, String pathApi = "/api", String pathWebSocket = "/ws", required AGeneralFrameworkApiSchemaApiValue generalSchemaApi})
UncompleteDocumentation

Properties

generalSchemaApi → AGeneralFrameworkApiSchemaApiValue
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
finalinherited
generalSchemaEnsureInitialized ↔ AGeneralFrameworkApiServerEnsureInitializedValue
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
pathApi → String
UncompleteDocumentation
final
pathWebSocket → String
UncompleteDocumentation
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serverUniverse → ServerUniverseNative
UncompleteDocumentation
final

Methods

decryptData({required String data}) → String
UncompleteDocumentation
dispose() → FutureOr<void>
GeneralLib
inherited
encryptData({required Map data}) → String
UncompleteDocumentation
ensureInitialized({required AGeneralFrameworkApiServerEnsureInitializedValue generalSchemaEnsureInitialized}) → FutureOr<void>
GeneralLib
override
getDetailStatusDeviceSupportAsync() → FutureOr<GeneralSchemaDeviceStatusSupportType>
GeneralLib
inherited
getDetailStatusDeviceSupportSync() → GeneralSchemaDeviceStatusSupportType
GeneralLib
inherited
getLibraryStatusTypeAsync() → FutureOr<GeneralSchemaLibraryStatusType>
GeneralLib
inherited
getLibraryStatusTypeSync() → GeneralSchemaLibraryStatusType
GeneralLib
inherited
initialized() → FutureOr<void>
GeneralLib
override
isDeviceSupportAsync() → FutureOr<bool>
GeneralLib
inherited
isDeviceSupportSync() → bool
GeneralLib
inherited
listen({int port = 3000, dynamic bindIp = '0.0.0.0'}) → FutureOr<void>
UncompleteDocumentation
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
valueBuilderAsync<T extends Object?>({required FutureOr<T> onValueBuilder(), required FutureOr<T> onErrorValueBuilder(dynamic error, StackTrace stackTrace)}) → FutureOr<T>
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
inherited
valueBuilderSync<T extends Object?>({required T onValueBuilder(), required T onErrorValueBuilder(dynamic error, StackTrace stackTrace)}) → T
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited