DeviceKeyboardStyle class

The keyboard style allows to customize the virtual onscreen keyboard visuals.

Constructors

DeviceKeyboardStyle({required Color backgroundColor, required Color button1BackgroundColor, required Color button1ForegroundColor, required Color button2BackgroundColor, required Color button2ForegroundColor})
Creates a new style for the virtual keyboard.
const
DeviceKeyboardStyle.dark()
A default dark theme for the virtual keyboard.
factory

Properties

backgroundColor → Color
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
final
button1BackgroundColor → Color
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
final
button1ForegroundColor → Color
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
final
button2BackgroundColor → Color
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
final
button2ForegroundColor → Color
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited