BoxIconData class

General Library Documentation Undocument By General Corporation & Global Corporation & General Developer

Inheritance

Constructors

BoxIconData(int code)
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
const

Properties

codePoint → int
The Unicode code point at which this icon is stored in the icon font.
finalinherited
fontFamily → String?
The font family from which the glyph for the codePoint will be selected.
finalinherited
fontFamilyFallback → List<String>?
The ordered list of font families to fall back on when a glyph cannot be found in a higher priority font family.
finalinherited
fontPackage → String?
The name of the package from which the font family is included.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
matchTextDirection → bool
Whether this icon should be automatically mirrored in right-to-left environments.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited