Flag class

General Library Documentation Undocument By General Corporation & Global Corporation & General Developer

Inheritance

Constructors

Flag(String? assetName, {Key? key, double? size = 35.0, ColorFilter? colorFilter})
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer

Properties

alignment → AlignmentGeometry
How to align the picture within its parent widget.
finalinherited
allowDrawingOutsideViewBox → bool
If true, will allow the SVG to be drawn outside of the clip boundary of its viewBox.
finalinherited
bytesLoader → BytesLoader
The BytesLoader used to resolve the SVG.
finalinherited
clipBehavior → Clip
The content will be clipped (or not) according to this option.
finalinherited
colorFilter → ColorFilter?
The color filter, if any, to apply to this widget.
finalinherited
errorBuilder → SvgErrorWidgetBuilder?
Widget displayed while the target image failed loading.
finalinherited
excludeFromSemantics → bool
Whether to exclude this picture from semantics.
finalinherited
fit → BoxFit
How to inscribe the picture into the space allocated during layout. The default is BoxFit.contain.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
height → double?
If specified, the height to use for the SVG. If unspecified, the SVG will take the height of its parent.
finalinherited
imageBuilder → SvgImageWidgetBuilder?
A builder that wraps the successfully loaded SVG widget.
finalinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
matchTextDirection → bool
If true, will horizontally flip the picture in TextDirection.rtl contexts.
finalinherited
placeholderBuilder → WidgetBuilder?
The placeholder to use while fetching, decoding, and parsing the SVG data.
finalinherited
renderingStrategy → RenderingStrategy
Widget rendering strategy used to balance flexibility and performance.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticsLabel → String?
The Semantics.label for this picture.
finalinherited
width → double?
If specified, the width to use for the SVG. If unspecified, the SVG will take the width of its parent.
finalinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
inherited
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited