ConcreteElementNode class

the default concrete node for ElementNode

Inheritance

Constructors

ConcreteElementNode({String tag = '', TextStyle? style})
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer

Properties

children → List<SpanNode>
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
finalinherited
childrenSpan → TextSpan
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
parent → SpanNode?
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
no setterinherited
parentStyle → TextStyle?
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style ↔ TextStyle?
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
getter/setter pairinherited
tag → String
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
final

Methods

accept(SpanNode? node) → void
use accept to add a child
inherited
build() → InlineSpan
General Library Documentation Undocument By General Corporation & Global Corporation & General Developer
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAccepted(SpanNode parent) → void
when this node was accepted by it's parent, onAccepted will be triggered
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited