FilePickerResult class

Constructors

FilePickerResult(List<PlatformFile> files)
const

Properties

count → int
The length of picked files.
no setter
files → List<PlatformFile>
Picked files.
final
hashCode → int
The hash code for this object.
no setteroverride
isSinglePick → bool
If this pick contains only a single resource.
no setter
names → List<String?>
A List<String> containing all names from picked files with its extensions.
no setter
paths → List<String?>
A List<String> containing all paths from picked files.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
xFiles → List<XFile>
Retrieves a List<XFile with all the files as XFile objects.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override