Skeleton class abstract

An interface for a skeleton annotation widget skeleton annotation widgets are used to configure or customize how the skeleton effect is applied to the child widget

Inheritance

Constructors

Skeleton({Key? key})
Default constructor
const
Skeleton.ignore({Key? key, required Widget child, bool ignore})
Creates a widget that ignores the child when SkeletonizerGeneralFramework.enabled is true
const
factory
Skeleton.ignorePointer({Key? key, required Widget child, bool ignore})
Creates a widget that ignores pointer events when SkeletonizerGeneralFramework.enabled is true
const
factory
Skeleton.keep({Key? key, required Widget child, bool keep})
Creates a widget that keeps paints the original child as is when SkeletonizerGeneralFramework.enabled is true
const
factory
Skeleton.leaf({Key? key, required Widget child, bool enabled})
Creates a widget that forces the child to have a painting effect e.g a Shimmer effect when SkeletonizerGeneralFramework.enabled is true
const
factory
Skeleton.replace({Key? key, required Widget child, bool replace, double? width, double? height, Widget replacement})
Creates a widget that replaces the child when SkeletonizerGeneralFramework.enabled is true
const
factory
Skeleton.shade({Key? key, required Widget child, bool shade})
Creates a widget that shades the child when SkeletonizerGeneralFramework.enabled is true This works as a ShaderMask but with a SkeletonizerGeneralFrameworkPaintingContext
const
factory
Skeleton.unite({Key? key, required Widget child, bool unite, BorderRadiusGeometry? borderRadius})
Creates a widget that unites the child with its descendants when SkeletonizerGeneralFramework.enabled is true
const
factory

Properties

enabled → bool
Whether the annotation is enabled
no setter
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → Element
Inflates this configuration to a concrete instance.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited