ImageGeneralUiGeneralFramework class

UncompleteDocumentation

Constructors

ImageGeneralUiGeneralFramework()
UncompleteDocumentation
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

imageGeneralUiOptionsDefault ↔ ImageGeneralUiGeneralFrameworkOptions
UncompleteDocumentation
getter/setter pair

Static Methods

decorationImage({required dynamic pathImage, ImageGeneralUiGeneralFrameworkOptions? imageGeneralUiOptions, void onError(Object error, StackTrace? stackTrace)?}) → DecorationImage
UncompleteDocumentation
decorationImageOrNull({required dynamic pathImage, ImageGeneralUiGeneralFrameworkOptions? imageGeneralUiOptions, void onError(Object error, StackTrace? stackTrace)?}) → DecorationImage?
UncompleteDocumentation
getImageGeneralUiGeneralFrameworkOptions({required ImageGeneralUiGeneralFrameworkOptions? imageGeneralUiOptions}) → ImageGeneralUiGeneralFrameworkOptions
UncompleteDocumentation
image({required dynamic pathImage, ImageGeneralUiGeneralFrameworkOptions? imageGeneralUiOptions, Image onNotFound()?}) → Image
UncompleteDocumentation
imageOrNull({required dynamic pathImage, ImageGeneralUiGeneralFrameworkOptions? imageGeneralUiOptions}) → Image?
UncompleteDocumentation