ImageGeneralUiGeneralFrameworkOptions class

UncompleteDocumentation

Constructors

ImageGeneralUiGeneralFrameworkOptions({ColorFilter? colorFilter, double? width, double? height, Widget errorBuilder(BuildContext context, Object error, StackTrace? stackTrace)?, BoxFit? fit})
UncompleteDocumentation
const

Properties

colorFilter → ColorFilter?
UncompleteDocumentation
final
errorBuilder → Widget Function(BuildContext context, Object error, StackTrace? stackTrace)?
UncompleteDocumentation
final
fit → BoxFit?
UncompleteDocumentation
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
UncompleteDocumentation
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double?
UncompleteDocumentation
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited