AlertGeneralFrameworkOptions class

UncompleteDocumentation

Constructors

AlertGeneralFrameworkOptions({required String title, required AlertGeneralFrameworkButtonFunction builder, bool isWithBlur = false, bool isAutoCloseOnConfirmBtnPressed = true, Color? color, BorderRadius? borderRadius, bool isShowCloseButton = true, bool barrierDismissible = true, String confirmText = "Ok", String cancelText = "Cancel", AlertGeneralFrameworkButtonFunction<void>? onCancelPressed, bool useRootNavigator = false, bool isShowCancelButton = true, AlertGeneralFrameworkButtonFunction<void>? onConfirmPressed})
UncompleteDocumentation

Properties

barrierDismissible → bool
UncompleteDocumentation
final
borderRadius → BorderRadius?
UncompleteDocumentation
final
builder → AlertGeneralFrameworkButtonFunction
UncompleteDocumentation
final
cancelText → String
UncompleteDocumentation
final
color → Color?
UncompleteDocumentation
final
confirmText → String
UncompleteDocumentation
final
hashCode → int
The hash code for this object.
no setterinherited
isAutoCloseOnConfirmBtnPressed → bool
UncompleteDocumentation
final
isShowCancelButton → bool
UncompleteDocumentation
final
isShowCloseButton → bool
UncompleteDocumentation
final
isWithBlur → bool
UncompleteDocumentation
final
onCancelPressed → AlertGeneralFrameworkButtonFunction<void>?
UncompleteDocumentation
final
onConfirmPressed → AlertGeneralFrameworkButtonFunction<void>?
UncompleteDocumentation
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
UncompleteDocumentation
final
useRootNavigator → bool
UncompleteDocumentation
final

Methods

copyWith({String? title, AlertGeneralFrameworkButtonFunction? builder, bool? isAutoCloseOnConfirmBtnPressed, Color? color, BorderRadius? borderRadius, bool? isShowCloseButton, bool? barrierDismissible, String? confirmText, String? cancelText, AlertGeneralFrameworkButtonFunction<void>? onCancelPressed, bool? useRootNavigator, bool? isShowCancelButton, AlertGeneralFrameworkButtonFunction<void>? onConfirmPressed}) → AlertGeneralFrameworkOptions
UncompleteDocumentation
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

onCancelPressedDefault(BuildContext context, AlertGeneralFrameworkOptions alertGeneralFrameworkOptions) → void
UncompleteDocumentation
onConfirmPressedDefault(BuildContext context, AlertGeneralFrameworkOptions alertGeneralFrameworkOptions) → void
UncompleteDocumentation