AppBarGeneralFrameworkWidget class

UncompleteDocumentationu

Inheritance
Implemented types

Constructors

AppBarGeneralFrameworkWidget({Key? key, Key? containerKey, bool isAddPaddingTop = true, required Size size, required Iterable<Widget> builder(BuildContext context), Widget widgetBuilder(BuildContext context, Widget child)?, DecorationBuilderGeneralFrameworkWidget? decorationBuilder, AlignmentGeometry? alignment, EdgeInsetsGeometry? padding, EdgeInsetsGeometry? margin, Clip clipBehavior = Clip.none})
UncompleteDocumentation
const

Properties

alignment → AlignmentGeometry?
UncompleteDocumentation
final
builder → Iterable<Widget> Function(BuildContext context)
UncompleteDocumentation
final
clipBehavior → Clip
UncompleteDocumentation
final
containerKey → Key?
UncompleteDocumentation
final
decorationBuilder → DecorationBuilderGeneralFrameworkWidget?
UncompleteDocumentation
final
hashCode → int
The hash code for this object.
no setterinherited
isAddPaddingTop → bool
UncompleteDocumentation
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margin → EdgeInsetsGeometry?
UncompleteDocumentation
final
padding → EdgeInsetsGeometry?
UncompleteDocumentation
final
preferredSize → Size
The size this widget would prefer if it were otherwise unconstrained.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → Size
UncompleteDocumentation
final
widgetBuilder → Widget Function(BuildContext context, Widget child)?
UncompleteDocumentation
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
contentWidget({required BuildContext context, required Widget child}) → Widget
UncompleteDocumentation
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

actionWindowWidget({required BuildContext context, required GeneralLibFlutterApp generalLibFlutterApp}) → Widget
backButtonWidget({required void onPressed()?, required BuildContext context, required GeneralLibFlutterStatefulWidget<StatefulWidget> generalLibFlutterStatefulWidget, required Widget backIcon}) → Widget
create({Key? key, required Widget? leadingBuilder(BuildContext context, Widget? child), required BuildContext context, required String title, DecorationBuilderGeneralFrameworkWidget? decorationBuilder, required GeneralLibFlutterStatefulWidget<StatefulWidget> pageState, bool isAddChangeTheme = true, bool isHideAppBarContent = false, required bool isShowApplicationIconAndtitle, required bool isApplicationFullScreen, required String applicationTitle, required dynamic applicationIcon, Widget? backIcon, required GeneralLibFlutterApp generalLibFlutterApp, required Iterable<Widget> actions(BuildContext context, GeneralLibFlutterStatefulWidget<StatefulWidget> pageState), required Iterable<Widget> builder(BuildContext context, GeneralLibFlutterStatefulWidget<StatefulWidget> pageState), required Widget appBarBuilder(BuildContext context, Widget appBar)}) → AppBarGeneralFrameworkWidget
decorationDefaultFunction(BuildContext context, BoxDecoration decoration) → Decoration
platformBrightness({required BuildContext context, required GeneralLibFlutterApp generalLibFlutterApp}) → Brightness
raw({Key? key, required BuildContext context, DecorationBuilderGeneralFrameworkWidget? decorationBuilder, required GeneralLibFlutterStatefulWidget<StatefulWidget> pageState, required GeneralLibFlutterApp generalLibFlutterApp, required bool isApplicationFullScreen, required bool isShowApplicationIconAndtitle, required dynamic applicationIcon, required String applicationTitle, required Iterable<Widget> builder(BuildContext context, GeneralLibFlutterStatefulWidget<StatefulWidget> pageState)}) → AppBarGeneralFrameworkWidget
themeChangeWidget({required GeneralLibFlutterApp generalLibFlutterApp}) → Widget