ChatControllerGeneralFramework<T extends MessageGeneralFramework> class

UncompleteDocumentation

Inheritance

Constructors

ChatControllerGeneralFramework({String key = "chat_page"})
UncompleteDocumentation

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
messages → Map<num, T>
UncompleteDocumentation
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollController → ScrollController
UncompleteDocumentation
no setter
scrollControllerAutoKeepStateData → ScrollControllerAutoKeepStateData
UncompleteDocumentation
final
selectedMessageId → num?
UncompleteDocumentation
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
addMessage({required T newMessage, bool isAutoScrollToLast = true}) → void
UncompleteDocumentation
addMessages({required Iterable<T> newMessages, bool isAutoScrollToLast = true}) → void
UncompleteDocumentation
dispose() → void
Discards any resources used by the object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
scrollToLast() → Future<void>
UncompleteDocumentation
scrollToMessageId({required num messageId}) → Future<bool>
UncompleteDocumentation
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited