FaqGeneralFrameworkData class

UncompleteDocumentation

Constructors

FaqGeneralFrameworkData({required String title, required List<FaqGeneralFrameworkSubData> data})
UncompleteDocumentation

Properties

data → List<FaqGeneralFrameworkSubData>
UncompleteDocumentation
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
UncompleteDocumentation
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited