detailPageFABlessGutterWidth property
Override the width of the gutter when there is no floating action button.
Implementation
final double? detailPageFABlessGutterWidth;
Override the width of the gutter when there is no floating action button.
final double? detailPageFABlessGutterWidth;