MasterDetailFlowWidgetProxy class

Interface for interacting with the MasterDetailFlowWidget.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openDetailPage(Object arguments) → void
Open detail page with arguments.
setInitialDetailPage(Object arguments) → void
Set the initial page to be open for the lateral layout. This can be set at any time, but will have no effect after any calls to openDetailPage.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited