MarkdownConfigGeneralFramework class

use MarkdownConfigGeneralFramework to set various configurations for MarkdownGeneralFrameworkWidget

Constructors

MarkdownConfigGeneralFramework({List<MarkdownWidgetConfig> configs = const []})
UncompleteDocumentation

Properties

a → LinkConfig
UncompleteDocumentation
no setter
blockquote → BlockquoteConfig
UncompleteDocumentation
no setter
code → CodeConfig
UncompleteDocumentation
no setter
h1 → HeadingConfig
UncompleteDocumentation
no setter
h2 → HeadingConfig
UncompleteDocumentation
no setter
h3 → HeadingConfig
UncompleteDocumentation
no setter
h4 → HeadingConfig
UncompleteDocumentation
no setter
h5 → HeadingConfig
UncompleteDocumentation
no setter
h6 → HeadingConfig
UncompleteDocumentation
no setter
hashCode → int
The hash code for this object.
no setterinherited
hr → HorizontalRulesConfig
UncompleteDocumentation
no setter
img → ImgConfig
UncompleteDocumentation
no setter
input → CheckBoxConfig
UncompleteDocumentation
no setter
li → ListConfig
UncompleteDocumentation
no setter
p → ParagraphMarkdownConfig
UncompleteDocumentation
no setter
pre → PreConfig
UncompleteDocumentation
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
table → TableConfig
UncompleteDocumentation
no setter

Methods

copy({List<MarkdownWidgetConfig> configs = const []}) → MarkdownConfigGeneralFramework
UncompleteDocumentation
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited