MarkdownFlutterContentGeneralFramework class

UncompleteDocumentation

Constructors

MarkdownFlutterContentGeneralFramework({required String title, required String content, required String languageCodeId})
UncompleteDocumentation
const

Properties

content → String
UncompleteDocumentation
final
hashCode → int
The hash code for this object.
no setterinherited
languageCodeId → String
UncompleteDocumentation
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
UncompleteDocumentation
final

Methods

copyWith({String? title, String? content, String? languageCodeId}) → MarkdownFlutterContentGeneralFramework
UncompleteDocumentation
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

empty() → MarkdownFlutterContentGeneralFramework
UncompleteDocumentation