TdNode class

UncompleteDocumentation

Inheritance

Constructors

TdNode(Map<String, String> attribute, WidgetVisitor visitor)
UncompleteDocumentation

Properties

attribute → Map<String, String>
UncompleteDocumentation
final
children → List<MarkdownSpanNodeGeneralFrameworkWidget>
UncompleteDocumentation
finalinherited
childrenSpan → TextSpan
UncompleteDocumentation
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
parent → MarkdownSpanNodeGeneralFrameworkWidget?
UncompleteDocumentation
no setterinherited
parentStyle → TextStyle?
UncompleteDocumentation
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style ↔ TextStyle?
UncompleteDocumentation
getter/setter pairinherited-setteroverride-getter
visitor → WidgetVisitor
UncompleteDocumentation
final

Methods

accept(MarkdownSpanNodeGeneralFrameworkWidget? node) → void
use accept to add a child
inherited
build() → InlineSpan
UncompleteDocumentation
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAccepted(MarkdownSpanNodeGeneralFrameworkWidget parent) → void
when this node was accepted by it's parent, onAccepted will be triggered
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited