PreConfig class

config class for pre

Implemented types

Constructors

PreConfig({EdgeInsetsGeometry padding = const EdgeInsets.all(16.0), Decoration decoration = const BoxDecoration(color: Color(0xffeff1f3), borderRadius: BorderRadius.all(Radius.circular(8.0))), EdgeInsetsGeometry margin = const EdgeInsets.symmetric(vertical: 8.0), TextStyle textStyle = const TextStyle(fontSize: 16), TextStyle? styleNotMatched, Map<String, TextStyle> theme = a11yLightTheme, String language = 'dart', CodeWrapper? wrapper, CodeBuilder? builder})
UncompleteDocumentation
const

Properties

builder → CodeBuilder?
UncompleteDocumentation
final
decoration → Decoration
UncompleteDocumentation
final
hashCode → int
The hash code for this object.
no setterinherited
language → String
UncompleteDocumentation
final
margin → EdgeInsetsGeometry
UncompleteDocumentation
final
padding → EdgeInsetsGeometry
UncompleteDocumentation
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
styleNotMatched → TextStyle?
the styleNotMatched is used to set a default TextStyle for code that does not match any theme.
final
tag → String
every config has a tag
no setteroverride
textStyle → TextStyle
UncompleteDocumentation
final
theme → Map<String, TextStyle>
see package:flutter_highlight/themes/
final
wrapper → CodeWrapper?
UncompleteDocumentation
final

Methods

copy({EdgeInsetsGeometry? padding, Decoration? decoration, EdgeInsetsGeometry? margin, TextStyle? textStyle, TextStyle? styleNotMatched, CodeWrapper? wrapper, Map<String, TextStyle>? theme, String? language}) → PreConfig
copy by other params
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

darkConfig → PreConfig
UncompleteDocumentation
no setter