LinkNode class

Tag: MarkdownTag.a

Link reference definitions, A link reference definition consists of a link label link will always be wrapped by other tags, such as MarkdownTag.p

Inheritance

Constructors

LinkNode(Map<String, String> attributes, LinkConfig linkConfig)
UncompleteDocumentation

Properties

attributes → Map<String, String>
UncompleteDocumentation
final
children → List<MarkdownSpanNodeGeneralFrameworkWidget>
UncompleteDocumentation
finalinherited
childrenSpan → TextSpan
UncompleteDocumentation
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
linkConfig → LinkConfig
UncompleteDocumentation
final
parent → MarkdownSpanNodeGeneralFrameworkWidget?
UncompleteDocumentation
no setterinherited
parentStyle → TextStyle?
UncompleteDocumentation
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style ↔ TextStyle
UncompleteDocumentation
getter/setter pairinherited-setteroverride-getter

Methods

accept(MarkdownSpanNodeGeneralFrameworkWidget? node) → void
use accept to add a child
inherited
build() → InlineSpan
UncompleteDocumentation
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAccepted(MarkdownSpanNodeGeneralFrameworkWidget parent) → void
when this node was accepted by it's parent, onAccepted will be triggered
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited