CodeNode class

Tag: MarkdownTag.code the code textSpan

Inheritance

Constructors

CodeNode(String text, CodeConfig codeConfig)
UncompleteDocumentation

Properties

children → List<MarkdownSpanNodeGeneralFrameworkWidget>
UncompleteDocumentation
finalinherited
childrenSpan → TextSpan
UncompleteDocumentation
no setterinherited
codeConfig → CodeConfig
UncompleteDocumentation
final
hashCode → int
The hash code for this object.
no setterinherited
parent → MarkdownSpanNodeGeneralFrameworkWidget?
UncompleteDocumentation
no setterinherited
parentStyle → TextStyle?
UncompleteDocumentation
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style ↔ TextStyle
UncompleteDocumentation
getter/setter pairinherited-setteroverride-getter
text → String
UncompleteDocumentation
final

Methods

accept(MarkdownSpanNodeGeneralFrameworkWidget? node) → void
use accept to add a child
inherited
build() → InlineSpan
UncompleteDocumentation
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAccepted(MarkdownSpanNodeGeneralFrameworkWidget parent) → void
when this node was accepted by it's parent, onAccepted will be triggered
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited