MarkdownSpanNodeGeneralFrameworkWidget class abstract

the basic node

Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
parent → MarkdownSpanNodeGeneralFrameworkWidget?
UncompleteDocumentation
no setter
parentStyle → TextStyle?
UncompleteDocumentation
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style ↔ TextStyle?
UncompleteDocumentation
getter/setter pair

Methods

build() → InlineSpan
UncompleteDocumentation
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAccepted(MarkdownSpanNodeGeneralFrameworkWidget parent) → void
when this node was accepted by it's parent, onAccepted will be triggered
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited