WidgetVisitor class

use WidgetVisitor that can transform MarkdownNode to MarkdownSpanNodeGeneralFrameworkWidgets and you can use MarkdownSpanNodeGeneralFrameworkWidget with Text.rich or RichText to get widget

Constructors

WidgetVisitor({MarkdownConfigGeneralFramework? config, List<MarkdownSpanNodeGeneralFrameworkWidgetGeneratorWithTag> generators = const [], MarkdownSpanNodeGeneralFrameworkWidgetAcceptCallback? onNodeAccepted, TextNodeGenerator? textGenerator, RichTextBuilder? richTextBuilder, RegExp? splitRegExp})
UncompleteDocumentation

Properties

config ↔ MarkdownConfigGeneralFramework
MarkdownConfigGeneralFramework is used to define the UI display
getter/setter pair
generators → List<MarkdownSpanNodeGeneralFrameworkWidgetGeneratorWithTag>
add your custom MarkdownSpanNodeGeneralFrameworkWidgetGeneratorWithTag to generators that you can customize the conversion of Nodes
final
hashCode → int
The hash code for this object.
no setterinherited
onNodeAccepted → MarkdownSpanNodeGeneralFrameworkWidgetAcceptCallback?
this function will be triggered when a MarkdownSpanNodeGeneralFrameworkWidget is accepted
final
richTextBuilder → RichTextBuilder?
use richTextBuilder to custom your own Text.rich
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
splitRegExp → RegExp?
use splitRegExp to split markdown data
final
textGenerator → TextNodeGenerator?
use textGenerator to custom your own TextNode
final

Methods

getNodeByElement(Element element, MarkdownConfigGeneralFramework config) → MarkdownSpanNodeGeneralFrameworkWidget
UncompleteDocumentation
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
visit(List<Node> nodes) → List<MarkdownSpanNodeGeneralFrameworkWidget>
visit will return a MarkdownSpanNodeGeneralFrameworkWidget list
visitElementAfter(Element element) → void
Called when an Element has been reached, after its children have been visited.
visitElementBefore(Element element) → bool
Called when an Element has been reached, before its children have been visited.
visitText(Text text) → void
Called when a Text node has been reached.

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

defaultSplitRegExp ↔ RegExp
UncompleteDocumentation
getter/setter pair