StoriesGeneralFrameworkWidget class

UncompleteDocumentation

Inheritance

Constructors

StoriesGeneralFrameworkWidget({Key? key, ImageFilter? blurFilter, ColorFilter? contentColorFilter, BlendMode blurBlendMode = BlendMode.srcOver, bool isWithBlur = false, bool isLoading = false, bool profileIsUseShadow = true, bool profileIsWithBorder = true, WidgetBuilderGeneralFrameworkWidget? contentBuilder, BorderRadiusGeometry? borderRadius, WidgetBuilderGeneralFrameworkWidget? titleBuilder, WidgetBuilderGeneralFrameworkWidget? profileBuilder, bool isUseShadow = true, void profileOnPressed()?, bool isWithBorder = true, required dynamic profile, required String title, required dynamic content, required void onPressed()?, required StoriesGeneralFrameworkWidgetStyle storiesGeneralFrameworkWidgetStyle})
UncompleteDocumentation
const

Properties

blurBlendMode → BlendMode
UncompleteDocumentation
final
blurFilter → ImageFilter?
UncompleteDocumentation
final
borderRadius → BorderRadiusGeometry?
UncompleteDocumentation
final
content → dynamic
UncompleteDocumentation
final
contentBuilder → WidgetBuilderGeneralFrameworkWidget?
UncompleteDocumentation
final
contentColorFilter → ColorFilter?
UncompleteDocumentation
final
hashCode → int
The hash code for this object.
no setterinherited
isLoading → bool
UncompleteDocumentation
final
isUseShadow → bool
UncompleteDocumentation
final
isWithBlur → bool
UncompleteDocumentation
final
isWithBorder → bool
UncompleteDocumentation
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onPressed → void Function()?
UncompleteDocumentation
final
profile → dynamic
UncompleteDocumentation
final
profileBuilder → WidgetBuilderGeneralFrameworkWidget?
UncompleteDocumentation
final
profileIsUseShadow → bool
UncompleteDocumentation
final
profileIsWithBorder → bool
UncompleteDocumentation
final
profileOnPressed → void Function()?
UncompleteDocumentation
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storiesGeneralFrameworkWidgetStyle → StoriesGeneralFrameworkWidgetStyle
UncompleteDocumentation
final
title → String
UncompleteDocumentation
final
titleBuilder → WidgetBuilderGeneralFrameworkWidget?
UncompleteDocumentation
final

Methods

body(BuildContext context) → Widget
UncompleteDocumentation
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited