MenuContainerGeneralFrameworkWidget class

UncompleteDocumentation

Inheritance

Constructors

UncompleteDocumentation
const

Properties

axis → Axis
UncompleteDocumentation
final
builder → WidgetBuilderGeneralFrameworkWidget?
UncompleteDocumentation
final
clipBehavior → Clip?
UncompleteDocumentation
final
constraints → BoxConstraints?
UncompleteDocumentation
final
crossAxisAlignment → CrossAxisAlignment
UncompleteDocumentation
final
decorationBuilder → DecorationBuilderGeneralFrameworkWidget?
UncompleteDocumentation
final
glowBorderRadius → BorderRadiusGeometry?
final
glowBorderSize → double
final
glowGradientColors → List<Color>?
final
glowSize → double
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
UncompleteDocumentation
final
isGlowOutside → bool
UncompleteDocumentait
final
isLoading → bool
UncompleteDocumentation
final
isWithBorder → bool
UncompleteDocumentation
final
isWithShadow → bool
UncompleteDocumentation
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
mainAxisAlignment → MainAxisAlignment
UncompleteDocumentation
final
mainAxisSize → MainAxisSize
UncompleteDocumentation
final
margin → EdgeInsetsGeometry?
UncompleteDocumentation
final
UncompleteDocumentation
final
padding → EdgeInsetsGeometry?
UncompleteDocumentation
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transform → Matrix4?
UncompleteDocumentation
final
transformAlignment → AlignmentGeometry?
UncompleteDocumentation
final
width → double?
UncompleteDocumentation
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

divider({required BuildContext context}) → Widget
UncompleteDocumentation
lisTile({required BuildContext context, bool isLoading = false, Widget? leading, Widget? trailing, bool isSelected = false, EdgeInsetsGeometry? contentPadding, required String title, Widget titleBuilder(BuildContext context, Text child)?, String subtitle = "", TextOverflow? subtitleTextOverflow, int? subtitleMaxLines, void onLongPress()?, void onTap()?, TextStyle textStyleBuilder(BuildContext context, TextStyle textStyle)?}) → Widget
UncompleteDocumentation
textStyleBuilderDefault(BuildContext context, TextStyle textStyle) → TextStyle
UncompleteDocumentation
title({required BuildContext context, EdgeInsetsGeometry? padding, AlignmentGeometry alignment = Alignment.center, required String title, TextStyle textStyleBuilder(BuildContext context, TextStyle textStyle)?, TextOverflow? textOverflow}) → Widget
UncompleteDocumentation
titleBuilderDefault(BuildContext context, Text child) → Widget
UncompleteDocumentation