RefreshGeneralFrameworkWidget class

Inheritance

Constructors

RefreshGeneralFrameworkWidget({Key? key, required Widget child, required bool isLastPage, required Future<void> onRefreshTop(), required Future<void> onRefreshBottom(), Widget? noMoreWidget, Widget? loadingWidget, EdgeInsetsGeometry? padding, ScrollController? scrollController})
const

Properties

child → Widget
Child widget | 子组件
final
hashCode → int
The hash code for this object.
no setterinherited
isLastPage → bool
Whether it is the last page, if it is true, you can not load more | 是否为最后一页,如果为true,则无法加载更多
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadingWidget → Widget?
Prompt widget when loading new data at the bottom | 正在加载数据时的提示组件
final
noMoreWidget → Widget?
Prompt text widget when there is no more data at the bottom | 底部没有更多数据时的提示文字组件
final
onRefreshBottom → Future<void> Function()
Callback function on pull up to load more data | 上拉以加载更多数据的回调函数
final
onRefreshTop → Future<void> Function()
Callback function on pull down to refresh | 下拉刷新时的回调函数
final
padding → EdgeInsetsGeometry?
Prompt padding for body if needed | 你可以自定义padding
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollController → ScrollController?
You can use your custom scrollController, or not | 你可以使用自定义的 ScrollController,或者不使用
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<RefreshGeneralFrameworkWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited