TabbarGeneralFrameworkWidget class

UncompleteDocumentation

Inheritance

Constructors

TabbarGeneralFrameworkWidget({Key? key, bool isLoading = false, required TabController? controller, required void onTap(int index)?, required List<Widget> tabs, bool isScrollable = false, EdgeInsetsGeometry? padding, Color? indicatorColor, bool automaticIndicatorColorAdjustment = true, double indicatorWeight = 2.0, EdgeInsetsGeometry indicatorPadding = EdgeInsets.zero, Decoration? indicator, TabBarIndicatorSize? indicatorSize, Color? dividerColor, double? dividerHeight, Color? labelColor, TextStyle? labelStyle, EdgeInsetsGeometry? labelPadding, Color? unselectedLabelColor, TextStyle? unselectedLabelStyle, DragStartBehavior dragStartBehavior = DragStartBehavior.start, WidgetStateProperty<Color?>? overlayColor, MouseCursor? mouseCursor, bool? enableFeedback, ScrollPhysics? physics, InteractiveInkFeatureFactory? splashFactory, BorderRadius? splashBorderRadius, TabAlignment? tabAlignment})
UncompleteDocumentation
const

Properties

automaticIndicatorColorAdjustment → bool
UncompleteDocumentation
final
controller → TabController?
UncompleteDocumentation
final
dividerColor → Color?
UncompleteDocumentation
final
dividerHeight → double?
UncompleteDocumentation
final
dragStartBehavior → DragStartBehavior
UncompleteDocumentation
final
enableFeedback → bool?
UncompleteDocumentation
final
hashCode → int
The hash code for this object.
no setterinherited
indicator → Decoration?
UncompleteDocumentation
final
indicatorColor → Color?
UncompleteDocumentation
final
indicatorPadding → EdgeInsetsGeometry
UncompleteDocumentation
final
indicatorSize → TabBarIndicatorSize?
UncompleteDocumentation
final
indicatorWeight → double
UncompleteDocumentation
final
isLoading → bool
UncompleteDocumentation
final
isScrollable → bool
UncompleteDocumentation
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelColor → Color?
UncompleteDocumentation
final
labelPadding → EdgeInsetsGeometry?
UncompleteDocumentation
final
labelStyle → TextStyle?
UncompleteDocumentation
final
mouseCursor → MouseCursor?
UncompleteDocumentation
final
onTap → void Function(int index)?
UncompleteDocumentation
final
overlayColor → WidgetStateProperty<Color?>?
UncompleteDocumentation
final
padding → EdgeInsetsGeometry?
UncompleteDocumentation
final
physics → ScrollPhysics?
UncompleteDocumentation
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
splashBorderRadius → BorderRadius?
UncompleteDocumentation
final
splashFactory → InteractiveInkFeatureFactory?
UncompleteDocumentation
final
tabAlignment → TabAlignment?
UncompleteDocumentation
final
tabs → List<Widget>
UncompleteDocumentation
final
unselectedLabelColor → Color?
UncompleteDocumentation
final
unselectedLabelStyle → TextStyle?
UncompleteDocumentation
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

builder({Key? key, bool isLoading = false, required TabController? controller, required void onTap(int index)?, required int itemCount, required Widget builder(bool isActiveOrSelected, int index), bool isScrollable = false, EdgeInsetsGeometry? padding, Color? indicatorColor, bool automaticIndicatorColorAdjustment = true, double indicatorWeight = 2.0, EdgeInsetsGeometry indicatorPadding = EdgeInsets.zero, Decoration? indicator, TabBarIndicatorSize? indicatorSize, Color? dividerColor, double? dividerHeight, Color? labelColor, TextStyle? labelStyle, EdgeInsetsGeometry? labelPadding, Color? unselectedLabelColor, TextStyle? unselectedLabelStyle, DragStartBehavior dragStartBehavior = DragStartBehavior.start, WidgetStateProperty<Color?>? overlayColor, MouseCursor? mouseCursor, bool? enableFeedback, ScrollPhysics? physics, InteractiveInkFeatureFactory? splashFactory, BorderRadius? splashBorderRadius, TabAlignment? tabAlignment}) → Widget
UncompleteDocumentation