TextFormFieldGeneralFrameworkWidget class

UncompleteDocumentation

Inheritance

Constructors

TextFormFieldGeneralFrameworkWidget({Key? key, TextInputType? keyboardType, bool autofocus = false, FocusNode? focusNode, int? minLines, int? maxLength, int? maxLines = 1, String? hintText, String? labelText, Widget prefixIconBuilder(BuildContext context, Widget child)?, IconData prefixIconData = Icons.people, Color color = Colors.white, TextEditingController? controller, String? validator(String? data)?, bool readOnly = false, bool obscureText = false, Widget? suffixIcon, InputDecorationBuilderGeneralFrameworkWidget? inputDecorationBuilder, required void onChanged(String value)?})
UncompleteDocumentation
const

Properties

autofocus → bool
UncompleteDocumentation
final
color → Color
UncompleteDocumentation
final
controller → TextEditingController?
UncompleteDocumentation
final
focusNode → FocusNode?
UncompleteDocumentation
final
hashCode → int
The hash code for this object.
no setterinherited
hintText → String?
UncompleteDocumentation
final
inputDecorationBuilder → InputDecorationBuilderGeneralFrameworkWidget?
UncompleteDocumentation
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardType → TextInputType?
UncompleteDocumentation
final
labelText → String?
UncompleteDocumentation
final
maxLength → int?
UncompleteDocumentation
final
maxLines → int?
UncompleteDocumentation
final
minLines → int?
UncompleteDocumentation
final
obscureText → bool
UncompleteDocumentation
final
onChanged → void Function(String value)?
UncompleteDocumentation
final
prefixIconBuilder → Widget Function(BuildContext context, Widget child)?
UncompleteDocumentation
final
prefixIconData → IconData
UncompleteDocumentation
final
readOnly → bool
UncompleteDocumentation
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suffixIcon → Widget?
UncompleteDocumentation
final
validator → String? Function(String? data)?
UncompleteDocumentation
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited