GeneralServicePublicClient<T extends GeneralFrameworkClient<GeneralFrameworkClientEnsureInitialized, GeneralFrameworkClientInvokeOptions, GeneralFrameworkClientInvokeOptions, GeneralFrameworkDatabase<GeneralFrameworkDatabaseEnsureInitialized>, GeneralFrameworkApiBase<GeneralFrameworkApiEnsureInitialized, GeneralFrameworkDatabase<GeneralFrameworkDatabaseEnsureInitialized>, dynamic>>> class abstract

UncompleteDocumentation

Implemented types

Constructors

GeneralServicePublicClient({required GeneralFrameworkClientFunction<T> generalFrameworkClientFunction})
UncompleteDocumentation

Properties

basePath ↔ String
UncompleteDocumentation
getter/setter pair
directoryBase → Directory
UncompleteDocumentation
no setter
directoryDatabase → Directory
UncompleteDocumentation
no setter
directoryFiles → Directory
UncompleteDocumentation
no setter
generalFrameworkClientFunction → GeneralFrameworkClientFunction<T>
UncompleteDocumentation
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

ensureInitialized({required String currentPath}) → FutureOr<void>
UncompleteDocumentation
ensureInitializedDirectory() → void
UncompleteDocumentation
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited