PackagexProjectGeneralFramework class

AutoGenerateBy Packagex

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

default_data → Map
AutoGenerateBy Packagex
no setter
default_data_to_string → String
AutoGenerateBy Packagex
no setter

Static Methods

isSame({required String data}) → bool
AutoGenerateBy Packagex