GeneralFrameworkDocumentation class

Generated

Inheritance
  • Object
  • JsonScheme
  • GeneralFrameworkDocumentation

Constructors

GeneralFrameworkDocumentation(Map rawData)
Generated

Properties

author_url_social_medias ↔ List<String>
Generated
getter/setter pair
content ↔ String?
Generated
getter/setter pair
description ↔ String?
Generated
getter/setter pair
documentations ↔ List<GeneralFrameworkDocumentationDocumentation>
Generated
getter/setter pair
Generated
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
Generated
getter/setter pair
rawData ↔ Map
return original data json
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
special_type ↔ String?
Generated
getter/setter pair
title ↔ String?
Generated
getter/setter pair

Methods

json_scheme_utils_checkDataIsSameBuilder({required bool onResult(Map rawData, Map defaultData)}) → bool
check value data whatever do yout want
json_scheme_utils_checkDataIsSameBySpecialType() → bool
check data if raw data
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map
return original data json
inherited
toMap() → Map
return original data json
inherited
toString() → String
return string data encode json original data
inherited
toStringPretty() → String
return string data encode json original data
inherited
utils_filter_by_keys(List keys) → Map
return original data json
inherited
utils_remove_by_keys(List keys) → Map
return original data json
inherited
utils_remove_by_keys_void(List keys) → void
GeneralLib
inherited
utils_remove_by_values(List values) → Map
return original data json
inherited
utils_remove_by_values_void(List values) → void
return original data json
inherited
utils_remove_values_null() → Map
return original data json
inherited
utils_remove_values_null_void() → void
return original data json
inherited

Operators

operator *(dynamic value) → dynamic
operator map data
inherited
operator +(dynamic value) → Map
operator map data
inherited
operator -(dynamic value) → Map
return original data json
inherited
operator /(dynamic value) → dynamic
operator map data
inherited
operator ==(Object other) → bool
The equality operator.
inherited
operator [](dynamic key) → dynamic
operator map data
inherited
operator []=(dynamic key, dynamic value) → void
operator map data
inherited

Static Properties

defaultData → Map
return default data
no setter

Static Methods

create({bool schemeUtilsIsSetDefaultData = false, String special_type = "generalFrameworkDocumentation", String? title, String? description, String? content, List<String>? author_url_social_medias, List<GeneralFrameworkDocumentationDocumentation>? documentations, GeneralFrameworkDocumentationFooter? footer}) → GeneralFrameworkDocumentation
Generated
override
empty() → GeneralFrameworkDocumentation
create GeneralFrameworkDocumentation Empty
override