GeneralFrameworkApiServer<T extends GeneralFrameworkApiBase<GeneralFrameworkDatabase> > class
abstract
UncompleteDocumentation
- Implemented types
Constructors
- GeneralFrameworkApiServer({required T generalFrameworkApi, required ServerUniverseNative serverUniverse, String pathApi = "/api", String pathWebSocket = "/ws"})
- UncompleteDocumentation
Properties
- generalFrameworkApi → T
-
UncompleteDocumentation
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- pathApi → String
-
UncompleteDocumentation
final
- pathWebSocket → String
-
UncompleteDocumentation
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serverUniverse → ServerUniverseNative
-
UncompleteDocumentation
final
Methods
-
decryptData(
{required String data}) → String -
UncompleteDocumentation
inherited
-
encryptData(
{required Map data}) → String -
UncompleteDocumentation
inherited
-
ensureInitialized(
{required String currentPath, required Client httpClient}) → FutureOr< void> - UncompleteDocumentation
-
invoke(
{required JsonScheme parameters}) → FutureOr< JsonScheme> - UncompleteDocumentation
-
listen(
{int port = 3000, dynamic bindIp = '0.0.0.0'}) → FutureOr< void> - UncompleteDocumentation
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited